package sgc.portal.cw.cw0902.persistence;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cs.cs0402.dto.CS04020001USearch;
import sgc.portal.cw.cw0902.dto.CW09020001USearch;

import java.util.List;
import java.util.Map;

@Mapper
public interface CW09020001UMapper {
	
	//주간보고작성  조회
	List<EasyHashMap<String, Object>> selectDeptZehrWeekWorkList(CW09020001USearch search);
	
	//주간보고작성 팝업  조회
	List<EasyHashMap<String, Object>> selectDeptZehrWeekWorkPopList(CW09020001USearch search);
	EasyHashMap<String, Object> selectDeptZehrWeekWorkPopTitleList(CW09020001USearch search);
	
	//동적조회 세팅
	List<EasyHashMap<String, Object>> selectHeaderUpList(CW09020001USearch search);
	List<EasyHashMap<String, Object>> selectHeaderDownList(CW09020001USearch search);
	List<EasyHashMap<String, Object>> selectHeaderCountList(CW09020001USearch search);
	String selectName(CW09020001USearch search);
	String selectDeptChk(CW09020001USearch search);
	
	List<EasyHashMap<String, Object>> selectDeptZehrWeekWorkPopFileList(CW09020001USearch search);
}
